@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Backends.py 13438 2022-04-27 06:01:35Z Jason $
+# $Id: Backends.py 13441 2022-05-04 04:19:40Z Jason $
 #
 # Copyright (c) 2021 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,22 +12,20 @@
 # limitations under the License.
 #
 # $Author: Jason $
-# $Date: 2022-04-27 14:01:35 +0800 (Wed, 27 Apr 2022) $
-# $Revision: 13438 $
+# $Date: 2022-05-04 12:19:40 +0800 (Wed, 04 May 2022) $
+# $Revision: 13441 $
 
 import re
 import json
 import requests
-    
-    
+
 from passlib.apache import HtpasswdFile
 
 from django.conf import settings
 from django.core.exceptions import PermissionDenied
-from django.contrib import messages
 from django.contrib.auth.backends import ModelBackend
 from django.contrib.auth.models import User
-DEFAULT_TRAC_AUTH_URL = getattr(settings, 
+DEFAULT_TRAC_AUTH_URL = getattr(settings,
     'DEFAULT_TRAC_AUTH_URL', 'https://code.nuwainfo.com/aec359bc3cfadb7504f26461a4c06625')
 DEFAULT_TRAC_AUTH_USERNAME = getattr(settings, 'DEFAULT_TRAC_AUTH_USERNAME', 'Deploy')
 DEFAULT_TRAC_AUTH_PASSWORD = getattr(settings, 'DEFAULT_TRAC_AUTH_PASSWORD', 'ei0W1aUeP1pcRvJoV4X8ZC2xm')
@@ -35,10 +33,10 @@ SET_TRAC_LOGIN_AS_STAFF = getattr(settings, "SET_TRAC_LOGIN_AS_STAFF", False)
 SET_TRAC_LOGIN_AS_SUPERUSER = getattr(settings, "SET_TRAC_LOGIN_AS_SUPERUSER", False)
 
 USER_DATA_PATTERN = r"#\s+?(\w+):\s+?(\{.+\}?)"
-  
+
 class TracBackend(ModelBackend):
 
-    def check(self, request, username, password, tracAuthURL=DEFAULT_TRAC_AUTH_URL, 
+    def check(self,request, username, password, tracAuthURL=DEFAULT_TRAC_AUTH_URL,
         tracUsername=DEFAULT_TRAC_AUTH_USERNAME, tracPassword=DEFAULT_TRAC_AUTH_PASSWORD):
         r = requests.get(tracAuthURL, auth=(tracUsername, tracPassword))
         content = r.text.strip()
@@ -48,29 +46,29 @@ class TracBackend(ModelBackend):
         user = data.get(username)
         if user:
             if not user.get("email"):
-                message = "No email in htfile for %s" % username
-                messages.add_message(request, messages.ERROR, message)
-                raise PermissionDenied()
+                return (False, "No email in htfile for %s" % username)
             else:
                 email = user.get("email")
             if ht.check_password(username, password):
                 return (True, email)
+            else:
+                return (False, 'Wrong password, please try again')
         else:
-            message = "No such user, please try again"
-            messages.add_message(request, messages.ERROR, message)
-            raise PermissionDenied()
+            return (False, 'No such user, please try again')
         return (False, None)
 
     def authenticate(self, request, username=None, password=None, **kwargs):
-        valid, email = self.check(request, username, password)
+        valid, info = self.check(request, username, password)
         if valid:
             try:
                 user = User.objects.get(username=username)
             except User.DoesNotExist:
                 # Create a new user. There's no need to set a password
-                user = User(username=username, email=email)
+                user = User(username=username, email=info)
                 user.is_staff = SET_TRAC_LOGIN_AS_STAFF
                 user.is_superuser = SET_TRAC_LOGIN_AS_SUPERUSER
                 user.save()
             return user
+        else:
+            raise PermissionDenied(info)
         return None
